/* Bluefish HTML Editor
 * html.c - menu/toolbar callbacks, inserting functions, and other cool stuff 
 *
 * Copyright (C) 
 * 1998 Olivier Sessink and Chris Mazuc
 * 1999-2000 Olivier Sessink
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "default_include.h"

#include <string.h>
#include <locale.h>

#include "cap.h"
#include "bluefish.h"
#include "html.h"
#include "init.h"
#include "gtk_easy.h"
#include "pixmaps.h"
/* #include "undo.h" */
#include "document.h"
#include "stringlist.h"

/*****************************************************************************/
/* function declarations */
void formdialog_cb(GtkWidget * widget, gpointer data);
void submitdialog_cb(GtkWidget * widget, gpointer data);
void resetdialog_cb(GtkWidget * widget, gpointer data);
void textareadialog_cb(GtkWidget * widget, gpointer data);
void hiddendialog_cb(GtkWidget * widget, gpointer data);
void textdialog_cb(GtkWidget * widget, gpointer data);
void radiodialog_cb(GtkWidget * widget, gpointer data);
void checkdialog_cb(GtkWidget * widget, gpointer data);
void selectdialog_cb(GtkWidget * widget, gpointer data);
void optiondialog_cb(GtkWidget * widget, gpointer data);
void formok(GtkWidget * widget, gpointer data);
void submitok(GtkWidget * widget, gpointer data);
void resetok(GtkWidget * widget, gpointer data);
void textok(GtkWidget * widget, gpointer data);
void hiddenok(GtkWidget * widget, gpointer data);
void textareaok(GtkWidget * widget, gpointer data);
void selectok(GtkWidget * widget, gpointer data);
void optionok(GtkWidget * widget, gpointer data);
void radiook(GtkWidget * widget, gpointer data);
void checkok(GtkWidget * widget, gpointer data);

/************************************************************************/

static void php_var_insert_cb(GtkWidget *widget, gpointer data) {
	gchar *tmp, *tmp2;
	tmp = gtk_editable_get_chars(GTK_EDITABLE(php_var_ins.src), 0, -1);
	if (strlen(tmp)) {
		tmp2 = g_strdup_printf("<?php if (isset($%s)) { echo $%s; } ?>",tmp,tmp);
		gtk_entry_set_text(GTK_ENTRY(php_var_ins.dest), tmp2);
		g_free(tmp2);
	}
	g_free(tmp);
}

GtkWidget *php_var_but(GtkWidget *src, GtkWidget *dest, GtkWidget *win) {
	GtkWidget *pixmap,*returnwid;

	php_var_ins.src = src;
	php_var_ins.dest = dest;
	
	returnwid = gtk_button_new();
	pixmap = new_pixmap(173, win->window, NULL);
	gtk_widget_show(pixmap);
	gtk_container_add(GTK_CONTAINER(returnwid), pixmap);
	gtk_signal_connect(GTK_OBJECT(returnwid), "clicked", php_var_insert_cb, NULL);
	gtk_widget_show(returnwid);
	return returnwid;
}


/************************************************************************/
void formdialog_cb(GtkWidget * widget, gpointer data)
{
	GList *methodlist = NULL;
	GList *enctypelist = NULL;

	static gchar *tagitems[] = { "action", "method", "enctype", "target", NULL };
	gchar *tagvalues[5];
	gchar *custom = NULL;
	Treplacerange *replace_range = NULL;

	/* this is for the right click menu */
	if ((data != NULL) && (widget == NULL)) {
		replace_range = values_for_dialog(tagitems, tagvalues, &custom, (Ttagpopup *) data);
	} else {
		init_values_for_dialog(tagitems, tagvalues);
	}
	/* end for the right click menu */


	create_dialog(500, 123, _("Form"));
	dialogtable = gtk_table_new(4, 10, 0);
	gtk_box_pack_start(GTK_BOX(vbox), dialogtable, FALSE, FALSE, 0);

	combo4 = combo_with_popdown(tagvalues[0], main_v->current_project.urllist, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Action")), 0, 1, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), combo4, 1, 8, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), file_but_new(GTK_WIDGET(GTK_COMBO(combo4)->entry), dialog, 0), 8, 10, 0, 1);
	
	methodlist = g_list_append(methodlist, "GET");
	methodlist = g_list_append(methodlist, "POST");
	combo1 = combo_with_popdown(tagvalues[1], methodlist, 1);
	g_list_free(methodlist);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Method")), 0, 1, 1, 2);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), GTK_WIDGET(GTK_COMBO(combo1)), 1, 2, 1, 2);

	/* I need to add more types */
	enctypelist = g_list_append(enctypelist, "application/x-www-form-urlencoded");
	enctypelist = g_list_append(enctypelist, "multipart/form-data");
	enctypelist = g_list_append(enctypelist, "text/plain");
	combo2 = combo_with_popdown(tagvalues[2], enctypelist, 1);
	g_list_free(enctypelist);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Enctype")), 3, 4, 1, 2);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), GTK_WIDGET(combo2), 4, 10, 1, 2);

	combo3 = combo_with_popdown(tagvalues[3], main_v->current_project.targetlist, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Target")), 0, 1, 2, 3);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), GTK_WIDGET(GTK_COMBO(combo3)), 1, 10, 2, 3);

	textentry2 = entry_with_text(custom, 1024);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Custom")), 0, 1, 3, 4);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry2, 1, 12, 3, 4);
	create_buttons(GTK_SIGNAL_FUNC(formok), (gpointer) replace_range);
	save_doc_selection();
	if (custom)
		g_free(custom);
}

/************************************************************************/
void submitdialog_cb(GtkWidget * widget, gpointer data)
{
	create_dialog(300, 100, _("Submit"));
	dialogtable = gtk_table_new(1, 10, 0);
	gtk_box_pack_start(GTK_BOX(vbox), dialogtable, FALSE, FALSE, 0);

	textentry1 = gtk_entry_new_with_max_length(256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry1, 1, 10, 0, 1);

	textentry2 = gtk_entry_new_with_max_length(256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Value")), 0, 1, 1, 2);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry2, 1, 10, 1, 2);

	create_buttons(GTK_SIGNAL_FUNC(submitok), NULL);
	save_doc_selection();
}

/************************************************************************/
void resetdialog_cb(GtkWidget * widget, gpointer data)
{
	create_dialog(300, 100, _("Reset"));
	dialogtable = gtk_table_new(1, 10, 0);
	gtk_box_pack_start(GTK_BOX(vbox), dialogtable, FALSE, FALSE, 0);

	textentry1 = gtk_entry_new_with_max_length(256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry1, 1, 10, 0, 1);

	textentry2 = gtk_entry_new_with_max_length(256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Value")), 0, 1, 1, 2);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry2, 1, 10, 1, 2);

	create_buttons(GTK_SIGNAL_FUNC(resetok), NULL);
	save_doc_selection();
}

/************************************************************************/
void textareadialog_cb(GtkWidget * widget, gpointer data)
{
	static gchar *tagitems[] = { "name", "value", "rows", "cols", NULL };
	gchar *tagvalues[5];
	gchar *custom = NULL;
	Treplacerange *replace_range = NULL;

	/* this is for the right click menu */
	if ((data != NULL) && (widget == NULL)) {
		replace_range = values_for_dialog(tagitems, tagvalues, &custom, (Ttagpopup *) data);
	} else {
		init_values_for_dialog(tagitems, tagvalues);
	}
	/* end for the right click menu */


	create_dialog(300, 145, _("Text area"));
	dialogtable = gtk_table_new(5, 10, 0);
	gtk_box_pack_start(GTK_BOX(vbox), dialogtable, FALSE, FALSE, 0);

	textentry1 = entry_with_text(tagvalues[0], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry1, 1, 10, 0, 1);

	spin1 = spinbut_with_value(tagvalues[2], 0, 500, 1.0, 5.0);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), spin1, 1, 2, 2, 3);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Rows")), 0, 1, 2, 3);

	spin2 = spinbut_with_value(tagvalues[3], 0, 500, 1.0, 5.0);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), spin2, 1, 2, 3, 4);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Cols")), 0, 1, 3, 4);

	textentry2 = entry_with_text(custom, 1024);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Custom")), 0, 1, 4, 5);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry2, 1, 10, 4, 5);

	create_buttons(GTK_SIGNAL_FUNC(textareaok), replace_range);
	save_doc_selection();
	if (custom)
		g_free(custom);
}


/************************************************************************/
void hiddendialog_cb(GtkWidget * widget, gpointer data)
{
	static gchar *tagitems[] = { "name", "value", "type", NULL };
	gchar *tagvalues[4];
	gchar *custom = NULL;
	Treplacerange *replace_range = NULL;

	/* this is for the right click menu */
	if ((data != NULL) && (widget == NULL)) {
		replace_range = values_for_dialog(tagitems, tagvalues, &custom, (Ttagpopup *) data);
	} else {
		init_values_for_dialog(tagitems, tagvalues);
	}
	/* end for the right click menu */


	create_dialog(300, 100, _("Hidden"));
	dialogtable = gtk_table_new(3, 10, 0);
	gtk_box_pack_start(GTK_BOX(vbox), dialogtable, FALSE, FALSE, 0);

	textentry1 = entry_with_text(tagvalues[0], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry1, 1, 10, 0, 1);

	textentry2 = entry_with_text(tagvalues[1], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Value")), 0, 1, 1, 2);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry2, 1, 10, 1, 2);

	textentry3 = entry_with_text(custom, 1024);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Custom")), 0, 1, 2, 3);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry3, 1, 10, 2, 3);

	create_buttons(GTK_SIGNAL_FUNC(hiddenok), replace_range);
	save_doc_selection();
	if (custom)
		g_free(custom);
}

/************************************************************************/
void textdialog_cb(GtkWidget * widget, gpointer data)
{
	GtkWidget *varbut;
	static gchar *tagitems[] = { "name", "value", "size", "maxlength", "type", NULL };
	gchar *tagvalues[6];
	gchar *custom = NULL;
	Treplacerange *replace_range = NULL;

	/* this is for the right click menu */
	if ((data != NULL) && (widget == NULL)) {
		replace_range = values_for_dialog(tagitems, tagvalues, &custom, (Ttagpopup *) data);
	} else {
		init_values_for_dialog(tagitems, tagvalues);
	}
	/* end for the right click menu */

	create_dialog(300, 145, _("Text"));
	dialogtable = gtk_table_new(4, 10, 0);
	gtk_box_pack_start(GTK_BOX(vbox), dialogtable, FALSE, FALSE, 0);

	textentry1 = entry_with_text(tagvalues[0], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry1, 1, 10, 0, 1);

	textentry2 = entry_with_text(tagvalues[1], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Value")), 0, 1, 1, 2);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry2, 1, 9, 1, 2);

	varbut = php_var_but(textentry1, textentry2, dialog);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), varbut, 9, 10, 1, 2);

	spin1 = spinbut_with_value(tagvalues[2], 0, 500, 1.0, 5.0);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), spin1, 1, 2, 2, 3);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Size")), 0, 1, 2, 3);

	spin2 = spinbut_with_value(tagvalues[3], 0, 500, 1.0, 5.0);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), spin2, 1, 2, 3, 4);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Max Length")), 0, 1, 3, 4);

	textentry3 = entry_with_text(custom, 1024);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Custom")), 0, 1, 4, 5);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry3, 1, 10, 4, 5);

	create_buttons(GTK_SIGNAL_FUNC(textok), replace_range);
	save_doc_selection();
	if (custom)
		g_free(custom);

}

/************************************************************************/
void radiodialog_cb(GtkWidget * widget, gpointer data)
{
	static gchar *tagitems[] = { "name", "value", "checked", "type", NULL };
	gchar *tagvalues[5];
	gchar *custom = NULL;
	Treplacerange *replace_range = NULL;

	/* this is for the right click menu */
	if ((data != NULL) && (widget == NULL)) {
		replace_range = values_for_dialog(tagitems, tagvalues, &custom, (Ttagpopup *) data);
	} else {
		init_values_for_dialog(tagitems, tagvalues);
	}
	/* end for the right click menu */


	create_dialog(300, 117, _("Radio Button"));
	dialogtable = gtk_table_new(4, 10, 0);
	gtk_box_pack_start(GTK_BOX(vbox), dialogtable, FALSE, FALSE, 0);

	textentry1 = entry_with_text(tagvalues[0], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry1, 1, 10, 0, 1);

	textentry2 = entry_with_text(tagvalues[1], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Value")), 0, 1, 1, 2);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry2, 1, 10, 1, 2);

	checkbox1 = gtk_check_button_new();
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), checkbox1, 1, 2, 2, 3);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Checked")), 0, 1, 2, 3);
	parse_existence_for_dialog(tagvalues[2], checkbox1);

	textentry3 = entry_with_text(custom, 1024);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Custom")), 0, 1, 3, 4);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry3, 1, 10, 3, 4);
	create_buttons(GTK_SIGNAL_FUNC(radiook), replace_range);
	save_doc_selection();
	if (custom)
		g_free(custom);


}

/************************************************************************/
void checkdialog_cb(GtkWidget * widget, gpointer data)
{
	static gchar *tagitems[] = { "name", "value", "checked", "type", NULL };
	gchar *tagvalues[5];
	gchar *custom = NULL;
	Treplacerange *replace_range = NULL;

	/* this is for the right click menu */
	if ((data != NULL) && (widget == NULL)) {
		replace_range = values_for_dialog(tagitems, tagvalues, &custom, (Ttagpopup *) data);
	} else {
		init_values_for_dialog(tagitems, tagvalues);
	}
	/* end for the right click menu */


	create_dialog(300, 117, _("Check Box"));
	dialogtable = gtk_table_new(4, 10, 0);
	gtk_box_pack_start(GTK_BOX(vbox), dialogtable, FALSE, FALSE, 0);

	textentry1 = entry_with_text(tagvalues[0], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry1, 1, 10, 0, 1);

	textentry2 = entry_with_text(tagvalues[1], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Value")), 0, 1, 1, 2);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry2, 1, 10, 1, 2);

	checkbox1 = gtk_check_button_new();
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), checkbox1, 1, 2, 2, 3);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Checked")), 0, 1, 2, 3);
	parse_existence_for_dialog(tagvalues[2], checkbox1);

	textentry3 = entry_with_text(custom, 1024);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Custom")), 0, 1, 3, 4);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry3, 1, 10, 3, 4);

	create_buttons(GTK_SIGNAL_FUNC(checkok), replace_range);
	save_doc_selection();
	if (custom)
		g_free(custom);

}

/************************************************************************/
void selectdialog_cb(GtkWidget * widget, gpointer data)
{
	static gchar *tagitems[] = { "name", "size", "multiple", NULL };
	gchar *tagvalues[4];
	gchar *custom = NULL;
	Treplacerange *replace_range = NULL;

	/* this is for the right click menu */
	if ((data != NULL) && (widget == NULL)) {
		replace_range = values_for_dialog(tagitems, tagvalues, &custom, (Ttagpopup *) data);
	} else {
		init_values_for_dialog(tagitems, tagvalues);
	}
	/* end for the right click menu */


	create_dialog(300, 123, _("Select"));
	dialogtable = gtk_table_new(4, 10, 0);
	gtk_box_pack_start(GTK_BOX(vbox), dialogtable, FALSE, FALSE, 0);

	textentry1 = entry_with_text(tagvalues[0], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry1, 1, 10, 0, 1);

	spin1 = spinbut_with_value(tagvalues[1], 0, 100, 1.0, 5.0);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), spin1, 1, 2, 1, 2);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Size")), 0, 1, 1, 2);

	checkbox1 = gtk_check_button_new();
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), checkbox1, 1, 2, 2, 3);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Multiple selections")), 0, 1, 2, 3);
	parse_existence_for_dialog(tagvalues[2], checkbox1);

	textentry2 = entry_with_text(custom, 1024);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Custom")), 0, 1, 3, 4);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry2, 1, 10, 3, 4);
	create_buttons(GTK_SIGNAL_FUNC(selectok), replace_range);
	save_doc_selection();
	if (custom)
		g_free(custom);

}

/************************************************************************/
void optiondialog_cb(GtkWidget * widget, gpointer data)
{
	static gchar *tagitems[] = { "value", "text", "label", "selected", NULL };
	gchar *tagvalues[5];
	gchar *custom = NULL;
	Treplacerange *replace_range = NULL;

	/* this is for the right click menu */
	if ((data != NULL) && (widget == NULL)) {
		replace_range = values_for_dialog(tagitems, tagvalues, &custom, (Ttagpopup *) data);
	} else {
		init_values_for_dialog(tagitems, tagvalues);
	}
	/* end for the right click menu */


	create_dialog(300, 123, _("Option"));
	dialogtable = gtk_table_new(4, 10, 0);
	gtk_box_pack_start(GTK_BOX(vbox), dialogtable, FALSE, FALSE, 0);

	textentry1 = entry_with_text(tagvalues[0], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Value")), 0, 1, 0, 1);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry1, 1, 10, 0, 1);

	textentry2 = entry_with_text(tagvalues[1], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Text")), 0, 1, 1, 2);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry2, 1, 10, 1, 2);

	textentry3 = entry_with_text(tagvalues[2], 256);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Label")), 0, 1, 2, 3);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), textentry3, 1, 10, 2, 3);

	checkbox1 = gtk_check_button_new();
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), checkbox1, 1, 2, 3, 4);
	gtk_table_attach_defaults(GTK_TABLE(dialogtable), gtk_label_new(_("Selected")), 0, 1, 3, 4);
	parse_existence_for_dialog(tagvalues[3], checkbox1);

	create_buttons(GTK_SIGNAL_FUNC(optionok), replace_range);
}

/************************************************************************/
void formok(GtkWidget * widget, gpointer data)
{
	gchar *thestring;

	thestring = g_strdup(cap("<FORM"));
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(combo4)->entry), cap("ACTION"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(combo1)->entry), cap("METHOD"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(combo2)->entry), cap("ENCTYPE"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(combo3)->entry), cap("TARGET"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(textentry2), NULL, thestring, NULL);
	stuff = g_strdup_printf("%s>", thestring);
	g_free(thestring);

	if (strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo3)->entry)))) {
		main_v->current_project.targetlist =
			add_to_stringlist(main_v->current_project.targetlist, gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo3)->entry)));
	}

	if (data == NULL) {
		restore_doc_selection();
		insert_text(stuff, cap("</FORM>"));
	} else {
		replace_text(stuff, ((Treplacerange *) data)->pos, ((Treplacerange *) data)->len);
		g_free(data);
	}

	destroy_dialog();
}

/************************************************************************/
void submitok(GtkWidget * widget, gpointer data)
{
	gchar *thestring;
	
	thestring = g_strdup(cap("<INPUT TYPE=\"SUBMIT\""));
	thestring = insert_string_if_entry(GTK_WIDGET(textentry1), cap("NAME"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(textentry2), cap("VALUE"), thestring, NULL);
	stuff = g_strdup_printf("%s>", thestring);
	g_free(thestring);

	restore_doc_selection();
	insert_text(stuff, NULL);

	destroy_dialog();
}

/************************************************************************/
void resetok(GtkWidget * widget, gpointer data)
{
	gchar *thestring;
	
	thestring = g_strdup(cap("<INPUT TYPE=\"RESET\""));
	thestring = insert_string_if_entry(GTK_WIDGET(textentry1), cap("NAME"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(textentry2), cap("VALUE"), thestring, NULL);
	stuff = g_strdup_printf("%s>", thestring);
	g_free(thestring);

	restore_doc_selection();
	insert_text(stuff, "");

	destroy_dialog();
}

/************************************************************************/
void textok(GtkWidget * widget, gpointer data)
{
	gchar *thestring;

	thestring = g_strdup(cap("<INPUT TYPE=\"TEXT\""));
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry1)), cap("NAME"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(spin1)), cap("SIZE"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(spin2)), cap("MAXLENGTH"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry2)), cap("VALUE"), thestring, NULL);	
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry3)), NULL, thestring, NULL);
	if (main_v->props.xhtml == 1) {
		stuff = g_strdup_printf("%s />", thestring);
	} else {
		stuff = g_strdup_printf("%s>", thestring);
	}
	g_free(thestring);

	if (data == NULL) {
		restore_doc_selection();
		insert_text(stuff, "");
	} else {
		replace_text(stuff, ((Treplacerange *) data)->pos, ((Treplacerange *) data)->len);
		g_free(data);
	}

	destroy_dialog();
}

/************************************************************************/
void hiddenok(GtkWidget * widget, gpointer data)
{
	gchar *thestring;

	thestring = g_strdup(cap("<INPUT TYPE=\"HIDDEN\""));
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry1)), cap("NAME"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry2)), cap("VALUE"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry3)), NULL, thestring, NULL);
	if (main_v->props.xhtml == 1) {
		stuff = g_strdup_printf("%s />", thestring);
	} else {
		stuff = g_strdup_printf("%s>", thestring);
	}
	g_free(thestring);

	if (data == NULL) {
		restore_doc_selection();
		insert_text(stuff, "");
	} else {
		replace_text(stuff, ((Treplacerange *) data)->pos, ((Treplacerange *) data)->len);
		g_free(data);
	}
	destroy_dialog();
}

/************************************************************************/
void textareaok(GtkWidget * widget, gpointer data)
{
	gchar *thestring;

	thestring = g_strdup(cap("<TEXTAREA"));
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry1)), cap("NAME"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(spin1)), cap("ROWS"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(spin2)), cap("COLS"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry2)), NULL, thestring, NULL);
	stuff = g_strdup_printf("%s>", thestring);
	g_free(thestring);

	if (data == NULL) {
		restore_doc_selection();
		insert_text(stuff, cap("</TEXTAREA>"));
	} else {
		replace_text(stuff, ((Treplacerange *) data)->pos, ((Treplacerange *) data)->len);
		g_free(data);
	}

	destroy_dialog();
}

/************************************************************************/
void selectok(GtkWidget * widget, gpointer data)
{
	gchar *thestring;

	thestring = g_strdup(cap("<SELECT"));
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry1)), cap("NAME"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(spin1)), cap("SIZE"), thestring, NULL);
	thestring = insert_attr_if_checkbox(checkbox1, cap("MULTIPLE"), thestring);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry2)), NULL, thestring, NULL);
	if (main_v->props.xhtml == 1) {
		stuff = g_strdup_printf("%s />", thestring);
	} else {
		stuff = g_strdup_printf("%s>", thestring);
	}
	g_free(thestring);

	if (data == NULL) {
		restore_doc_selection();
		insert_text(stuff, cap("\n</SELECT>"));
	} else {
		replace_text(stuff, ((Treplacerange *) data)->pos, ((Treplacerange *) data)->len);
		g_free(data);
	}

	destroy_dialog();
}

/************************************************************************/
void optionok(GtkWidget * widget, gpointer data)
{
	gchar *thestring;

	thestring = g_strdup(cap("<OPTION"));
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry1)), cap("VALUE"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry3)), cap("LABEL"), thestring, NULL);
	thestring = insert_attr_if_checkbox(checkbox1, cap("SELECTED"), thestring);
	stuff = g_strdup_printf("%s>", thestring);
	g_free(thestring);
	/* hmm this is not really like in the other dialogs.... */
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry2)), NULL, stuff, NULL);
	stuff = thestring;

	if (data == NULL) {
		insert_text(stuff, cap("</option>"));
	} else {
		replace_text(stuff, ((Treplacerange *) data)->pos, ((Treplacerange *) data)->len);
		g_free(data);
	}
	destroy_dialog();
}

/************************************************************************/
void radiook(GtkWidget * widget, gpointer data)
{
	gchar *thestring;

	thestring = g_strdup(cap("<INPUT TYPE=\"RADIO\""));
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry1)), cap("NAME"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry2)), cap("VALUE"), thestring, NULL);
	thestring = insert_attr_if_checkbox(checkbox1, cap("CHECKED"), thestring);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry3)), NULL, thestring, NULL);
	if (main_v->props.xhtml == 1) {
		stuff = g_strdup_printf("%s />", thestring);
	} else {
		stuff = g_strdup_printf("%s>", thestring);
	}
	g_free(thestring);

	if (data == NULL) {
		restore_doc_selection();
		insert_text(stuff, "");
	} else {
		replace_text(stuff, ((Treplacerange *) data)->pos, ((Treplacerange *) data)->len);
		g_free(data);
	}

	destroy_dialog();
}

/************************************************************************/
void checkok(GtkWidget * widget, gpointer data)
{
	gchar *thestring;

	thestring = g_strdup(cap("<INPUT TYPE=\"CHECKBOX\""));
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry1)), cap("NAME"), thestring, NULL);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry2)), cap("VALUE"), thestring, NULL);
	thestring = insert_attr_if_checkbox(checkbox1, cap("CHECKED"), thestring);
	thestring = insert_string_if_entry(GTK_WIDGET(GTK_ENTRY(textentry3)), NULL, thestring, NULL);
	if (main_v->props.xhtml == 1) {
		stuff = g_strdup_printf("%s />", thestring);
	} else {
		stuff = g_strdup_printf("%s>", thestring);
	}
	g_free(thestring);

	if (data == NULL) {
		restore_doc_selection();
		insert_text(stuff, "");
	} else {
		replace_text(stuff, ((Treplacerange *) data)->pos, ((Treplacerange *) data)->len);
		g_free(data);
	}

	destroy_dialog();
}
